Coverage report

File |  | statements | missing | excluded |  | coverage
--- | --- | --- | --- | --- | --- | ---
jinja2_async_environment / bccache.py |  | 57 | 0 | 3 |  | 100%
jinja2_async_environment / caching / manager.py |  | 145 | 13 | 5 |  | 91%
jinja2_async_environment / caching / strategies.py |  | 241 | 82 | 0 |  | 66%
jinja2_async_environment / caching / typed.py |  | 120 | 0 | 0 |  | 100%
jinja2_async_environment / caching / unified.py |  | 63 | 0 | 6 |  | 100%
jinja2_async_environment / compiler.py |  | 8 | 0 | 0 |  | 100%
jinja2_async_environment / compiler_modules / cache.py |  | 18 | 0 | 0 |  | 100%
jinja2_async_environment / compiler_modules / codegen.py |  | 588 | 111 | 21 |  | 81%
jinja2_async_environment / compiler_modules / dependencies.py |  | 40 | 1 | 0 |  | 98%
jinja2_async_environment / compiler_modules / frame.py |  | 69 | 0 | 3 |  | 100%
jinja2_async_environment / compiler_modules / loops.py |  | 27 | 4 | 0 |  | 85%
jinja2_async_environment / compiler_modules / patterns.py |  | 44 | 0 | 1 |  | 100%
jinja2_async_environment / environment.py |  | 235 | 20 | 5 |  | 91%
jinja2_async_environment / loaders / base.py |  | 123 | 24 | 27 |  | 80%
jinja2_async_environment / loaders / choice.py |  | 53 | 13 | 0 |  | 75%
jinja2_async_environment / loaders / dict.py |  | 47 | 8 | 0 |  | 83%
jinja2_async_environment / loaders / filesystem.py |  | 106 | 35 | 0 |  | 67%
jinja2_async_environment / loaders / function.py |  | 90 | 16 | 0 |  | 82%
jinja2_async_environment / loaders / package.py |  | 186 | 58 | 4 |  | 69%
jinja2_async_environment / testing / context.py |  | 31 | 5 | 0 |  | 84%
jinja2_async_environment / testing / fixtures.py |  | 28 | 0 | 1 |  | 100%
Total |  | 2319 | 390 | 76 |  | 83%

No items found using the specified filter.